bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 28. Aventiure
___________________________________________________ #### Aventivre wie die nibelvnge ze ezeln bvrge chomen #### vnd wie si da enpfangen wrden
###### 1718 | ### Do di bvergonden | chomen in eceln lant ### do gevriesh ez von berne | der alte hildebrant ### er sagtez sinem herren | ez was im harte leit ### er bat in wol enpfahen | di ritter chvene vnt gemeit
###### 1719 | ### wolfhart der snelle | hiez bringen div march ### do reit mit dieteriche | vil manich degen starch ### da er si grvezen wolde | zv zin an daz velt ### da hetens vf gebvnden | vil manich herlich gezelt
###### 1720 | ### do si von tronege hagen | verrest riten sach ### zv den sinen herren | gezogenlich er sprach ### nv svlt ir snelle rechen | von den sedeln stan ### vnd get im hin engegene | div ivch da wellent enpfah
###### 1721 | ### dort chvmt her ein gesinde | daz ist mir wol bechant ### ez sint vil snelle degene | von amelvnge lant ### di fvert der von berne | di sint vil hohgemvt ### ir svlt iz niht versmahen | swaz man iv dieneste getvt
###### 1722 | ### do stvnden von den rossen | daz was michel reht ### neben dieteriche manich | ritter vnd kneht ### si giengen zv den gesten | da man di helde vant ### si grvozten minnechlichen | di von bvrgonden lant
###### 1723 | ### do si der herre dieterich | gegen im chomen sach ### hie mveget ir gerne hoeren | waz do der degen sprach ### zv den vten chinden | ir reise was im leit ### er wand ez wiste rvedger | daz erz in hete geseit
###### 1724 | ### sit willechomen ir herren | gvnther vnd giselher ### gernot vnde hagene | sam si her voelker ### vnt danchwart der vil snelle | ist iv daz niht bechant ### criemhilt noh sere weinet | den helt von nibelvnge lant
###### 1725 | ### si mach wol lange weinen | sprach do hagene ### er lit von manigem iare gar | ce tode erslagene ### den kvenech von den hivnen | den sol si holden haben ### sifrit chvmt niht widere | er ist vor maniger zit begraben
###### 1726 | ### di sifrides wunden | lazen wir nv sten ### sol leben div vrowe crimhilt | noch mag schade ergen ### so redet von berne | der herre dieterich ### trost der nibelvnge | davor behvete dv dich
###### 1727 | ### wi sol ich mich behevten | sprach der ### ecel vns boten sande | wes sol ich vragen mer ### daz wir zv zim solden | riten her in daz lant ### ovch hat vns menigiv maere | min swester criemhilt gesant
###### 1728 | ### ich chan iv wol geraten | sprach aber hagene ### ni bitet iv div maere | baz ce sagene ### den herren dieterichen | vnt sine helde gvt ### daz si ivch laze wizen | der vrovn crimhilde mvt
###### 1729 | ### do giengen svnder sprachen | di drie kvenge rich ### gventher vnd gernot | vnd ovch her dieterich ### nv sage vns von berne | vil edel ritter gvt ### wi dir si gewizen | vmb der chveneginne mvt
###### 1730 | ### do sprach der voget von berne | waz sol ich mere sagen ### ich hoer alle morgen | weinen vnd klagen ### mit iamerlichen sitten | daz eceln wip ### dem richen got von himele | des starchen sifrides lip
###### 1731 | ### ez ist et vnerwendet | sprach der chvene man ### volker der videlaere | daz wir vernomen han ### wir svln ce hove riten | vnd svln lazen sehen ### waz vns vil snellen degenen | da cen hivnen mvege geshehen
###### 1732 | ### di chvnen bvrgonden | hin ze hove ritten ### si chomen herliche | nach des landes sitten ### do wunderte da cen hivnen | vil manegen chvenen man ### vmb hagen von tronege | wi der waere getan
###### 1733 | ### dvrch daz man sagete maere | des was im genvch ### daz er von niderlande | sifriden slvch ### sterchest aller recken | den crimhilde man ### des wart michel vrage | ce hove nach hagene getan
###### 1734 | ### der helt was wol gewahsen | daz ist alwar ### groz was er cen brvsten | gemischet was sin har ### mit einer grisen varwe | div bein warn im lanch ### vnd eislich sin gesihene | er hete herlichen ganch
###### 1735 | ### do hiez man herbergen | di bvergonden man ### gvntheres ingesinde | daz wart gesvndert dan ### daz riet | div im vil hazes trvch ### da von man sit di knehte | in der herberge slvch
###### 1736 | ### danchwart hagen brvder | der was marshalch ### der kvnech im sin gesinde | vlizechlich bevalch ### daz er ir vil wol pflege | vnd in gaebe genvch ### der helt von bvrgonden | in allen gvten willen trvch
###### 1737 | ### criemhilt div schone | mit ir gesinde gie ### da si di nibelvnge | mit valschem mvt enpfie ### si chvste giselhern | vnd nam in bi der hant ### daz sah von tronege hagene | den helm er vaste gebant
###### 1738 | ### nach svs getanem grvze | sprach do hagene ### mvegen sich verdenchen | snelle degene ### man grvzet svnderlingen | di chvene vnd ir man ### wir haben niht gvter reise | zv dirre hohgezit getan
###### 1739 | ### si sprach sit willechomen | swer ivch gerne siht ### dvrch iwer selbes frivntschaft | so grveze ich iwer niht ### saget waz ir mir bringet | von wormez vber rin ### darvmb ir mir so groze | soldet willechomen sin
###### 1740 | ### het ich gewest div maere | sprach do hagene ### daz iv gabe solden | bringen degene ### ich waere wol so riche | het ich mich baz verdaht ### daz ich iv mine gabe | her ce lande hete braht
###### 1741 | ### nv svlt ir mich der maere | mere wizen lan ### hort der nibelvnge | war habt ir den getan ### der was doh min eigen | daz ist wol bechant ### den soldet ir mir fveren | in daz eceln lant
###### 1742 | ### entriwen min vrov criemhilt | des ist vil manech tach ### daz ich hort der nibelvnge | nie gepflach ### den hiezn mine herren | senchen in den rin ### da mvz er waerliche | vnz an daz ivngeste sin
###### 1743 | ### do sprach div chvneginne | ich hans ovch gedaht ### ir habt mirs noch vil wenich | her ce lande braht ### swi er min eigen waere | vnde ich sin wilen pflach ### des han ich alle zite | vil manigen trvrigen tach
###### 1744 | ### ia bringe ich iv den tivel | sprach aber hagene ### ich han an minem schilde | so vil ce tragene ### vnd an der minen brvenne | min helm der ist so lieht ### daz swert an miner hende | des en bringe ich iv nieht
###### 1745 | ### do sprach div chvneginne | cen recken veber al ### man sol decheiniv waffen | tragen in den sal ### ir helde ir svlt mirs vfgebe | ich wil si behalten lan ### entriwen sprach do hagene | ez wirdet nimmer getan
###### 1746 | ### ia ne ger ich niht der eren | fvrsten wine milt ### daz ir cen herbergen | trveget minen schilt ### vnde ander min geweffen | ir sit ein chvenegin ### daz en lerte mich niht min vater | ich wil selbe kameraere sin
###### 1747 | ### owe miner leide | sprach do vrov criemhilt ### warvmbe wil min brvder | vnd hagen sinen schilt ### niht lazen behalten | si sint gewarnot ### vnd wesse ich waer daz taete | der mvese chiesen den tot
###### 1748 | ### des antwurte ir mit zorne | der fverste dieterich ### ich pin iz der hat gewarnet | di edeln chvnege rich ### vnd hagen den chvenen | den bvrgonden man ### nv zv valandinne | dv ne solt michs niht geniezzen lan
###### 1749 | ### des schamte sich vil sere | daz eceln wip ### si vorhte bitterlichen | den dieteriches lip ### do gi si von im balde | daz si nine sprach ### wan daz si swinde bliche | an ir viande sah
###### 1750 | ### be henden sich do viengen | zwene degene ### daz eine was her dieterich | daz ander hagene ### do sprach gezogenliche | der recke vil gemeit ### daz iwer chomen cen hivnen | daz ist mir waerliche leit
###### 1751 | ### dvrch daz div chveneginne | daz gesprochen hat ### do sprach von tronege hagene | es wirt wol alles rat ### svs redeten mit einander | di zwene chvene man ### daz der kvenech ecel | darvmbe vragen began
###### 1752 | ### div maere weste ich gerne | sprach der kvenech rich ### wer der recke waere | den dort her dieterich ### so frivntlich enpfahet | er treit vil hohen mvt ### swer sin vater waere | er mach wol sin ein helt gvt
###### 1753 | ### des antwurte dem chvenege | ein crimhilde man ### er ist geborn von tronege | sin vater hiez aldrian ### swi blid er hie gebare | er ist ein grimmer man ### ich laze ivch daz wol schowen | daz ich gelogen nine han
###### 1754 | ### wi sol ich daz erchennen | daz er so grimmech ist ### dannoch er nine vesse | vil manigen argen list ### den sit div chveneginne an | ir magen begie ### daz si mit dem lebene | deheinen von den hivnen lie
###### 1755 | ### wol erchande ich aldrianen | der was min man ### lob vnde michel ere | er hi bi mir gewan ### ich machete in ce ritter | vnd gap im min golt ### helche div getriwe | was im innechlichen holt
###### 1756 | ### davon ich wol erchenne | allererst wer si sint ### ez wurden mine gisel | zwei waetlichiv chint ### er vnde von spanye walther | di wuhsen hi ce man ### hagen sande ich wider heim | walther mit hiltegvnt entran
###### 1757 | ### er gedahte langer maere | div warn e geschehen ### sinen frivnt von tronege | den het er reht ersehen ### der im in siner ivgende | vil starchiv dienest bot ### sit frvmt er im in alter | vil manigen lieben vrivnt tot

<<< Übersicht <<< vorige Seite nächste Seite >>>